
# Type: jsonpath

A string encoding a JSON Path. The value of the string MUST conform to JSON Point syntax and SHOULD dereference to zero or more valid objects within the current instance document when encoded in tree form.

URI: [linkml:Jsonpath](https://w3id.org/linkml/Jsonpath)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **str** |
| Representation | | str |
